#
# spec file for package kcoreaddons
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5CoreAddons5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kcoreaddons
Version:        5.116.0
Release:        1.2
Summary:        Utilities for core application functionality and accessing the OS
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  shared-mime-info
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5LinguistTools) >= %{qt5_version}
Requires:       shared-mime-info

%description
KCoreAddons provides classes built on top of QtCore to perform various tasks
such as manipulating mime types, autosaving files, creating backup files,
generating random sequences, performing text manipulations such as macro
replacement, accessing user information and many more.

%package -n %{lname}
Summary:        Utilities for core application functionality and accessing the OS
%requires_ge    libQt5Core5
Recommends:     %{name} = %{version}

%description -n %{lname}
KCoreAddons provides classes built on top of QtCore to perform various tasks
such as manipulating mime types, autosaving files, creating backup files,
generating random sequences, performing text manipulations such as macro
replacement, accessing user information and many more.

%package devel
Summary:        Utilities for core application functionality and accessing the OS
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
Requires:       cmake(Qt5Core) >= %{qt5_version}

%description devel
KCoreAddons provides classes built on top of QtCore to perform various tasks
such as manipulating mime types, autosaving files, creating backup files,
generating random sequences, performing text manipulations such as macro
replacement, accessing user information and many more. Development files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -Dlconvert_executable=%{_kf5_libdir}/qt5/bin/lconvert -DKDE4_DEFAULT_HOME=".kde4"
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}

%find_lang %{name} --all-name --with-qt --without-mo

%ldconfig_scriptlets -n %{lname}

%files lang -f %{name}.lang

%files
%{_kf5_appsdir}/mime/packages/kde5.xml
%{_kf5_datadir}/

%files -n %{lname}
%license LICENSES/*
%doc README*
%{_kf5_debugdir}/kcoreaddons.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5CoreAddons.so.*

%files devel
%{_kf5_bindir}/desktoptojson
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5CoreAddons/
%{_kf5_libdir}/libKF5CoreAddons.so
%{_kf5_mkspecsdir}/qt_KCoreAddons.pri

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- Changes since 5.114.0:
  * Add isProcExists func to check if /proc exists
  * Determine UNIX process if "/proc" does not exist
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- Changes since 5.113.0:
  * Fix license text loading on Android
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- Changes since 5.112.0:
  * Make testLoadHints pass with the PatchCollection
  * KAboutLicense::byKeyword: handle SPDX ids with -or-later
  * kdirwatch: find fam as part of the tests now that we include _p.h
  * kdirwatch: don't crash after moving threads
  * kdirwatch: don't leave relative entries dangling
  * kdirwatch: expand ref counting system to keep account of public instances
  * kdirwatch: always unref d, and unset d from inside d
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- Changes since 5.111.0:
  * Fix API docs generation for KPluginMetaDataOption enum values
  * Deprecate unused KStringHandler::isUtf8 & KStringHandler::from8Bit
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- Changes since 5.110.0:
  * Unset bug address for implicitly created KAboutData (kde#473517)
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- Changes since 5.109.0:
  * KFileSystemType: recognize ntfs3
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * kurlmimedata: limit amount of in-flight FDs for portal submission (kde#472716)
  * Remove code variants for building with Qt 6
  * kurlmimedata: don't portal symlinks (kde#464225)
  * KSignalHandler: possibility to register signal handler as early as possible
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- Changes since 5.106.0:
  * use fcntl to fix macOS compile
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- Changes since 5.105.0:
  * exportUrlsToPortal: let it work in a non-KDE session (kde#458643)
  * exportUrlsToPortal: don't export when there are non-sendable non-local files
  * KDirWatch: Don't append fileName to fileName in Delete event (kde#467095)
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- Changes since 5.104.0:
  * Prevent KSignalHandler leaking signalfd file descriptors
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Deprecate KPluginMetaData::initialPreference
  * Convert BugReportUrl in desktoptojson
  * exportUrlsToPortal: stop fusing remote urls
  * Show deprecation warning about desktoptojson tool
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- Changes since 5.102.0:
  * don't needlessly copy urls while iterating
  * KSandbox: Warn when running without flatpak-spawn privileges
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Config.cmake.in: workaround Inotify static issue
  * Better Pluralize 'n minutes ago' (kde#462261)
  * Fix portal urls cache on X11 (kde#460314)
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * [KJobTrackerInterface] qRegisterMetatype KJob::Unit
  * Remove unused variable
  * Perform initialization in initialization list
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Add missing . in error string
  * KPluginMetaData: Check applicationDirPath first when resolving plugin
    paths (kde#459830)
  * Fix static build of downstream consumers
  * Fix the translation folder name
  * KFileSystem: add Fuse Type; use libudev to probe underlying fuseblk type
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Remove unused includes
  * Show all headers in qtc6
  * Cache portal urls
  * Add new bugReportUrl standard metadata property
  * KSignalHandler: Fix documentation
  * Add Qt 6 Windows CI
  * .gitlab-ci.yml: enable static builds
  * Add support for static builds
  * Fix moc configuration of K_PLUGIN_CLASS macro
  * Use a non-deprecated notify signal for the KJob::percent property
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * kcoreaddons_add_plugin: Add cmake option to skip plugin installation in autotests
  * Remove extra semi colon
  * Add FreeBSD Qt 6 CI
  * kfuzzymatchertest replace "QStringLiteral("")" with "QString("")"
  * Fix KUrlMimeData::exportUrlsToPortal for mixed files-and-directories URIs
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Deprecate KMessage system
  * KUserGroup: fix data race by porting from getgrgid to getgrgid_r
  * KUserGroup: centralize calls to getgrgid(), at least for constructors
  * KUser: fix data race by porting to getpwuid_r and getpwnam_r
  * KUser: use member initialization, call getpwuid in a single place
  * fix up the kpluingmetadata::value doc
  * Add KRuntimePlatform as alternative for KDeclarative::runtimePlatform
  * Fix klibexectest when build dir path contains symlink
  * Fix unit tests in kpluginfactorytest
  * Bump shared-mime-info to 1.8
  * make kprocess a more proper qprocess
  * new ksandbox function to start processes
  * refresh git-blame-ignore-revs for latest clang-format run
  * automatic clang-format run (clang 14)
  * Adapt libexec paths for KF6
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Remove duplicate header between cpp/h files
  * Add missing errno header
  * xdg drag and drop portal support
  * Install KMemoryInfo headers
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * KPluginFactory: Create un-deprecated overload to register CreateInstanceWithMetaDataFunction
  * KSignalHandler: add error warnings when reading or writing signal
  * Use the versionless KDE_INSTALL_FULL_KSERVICETYPESDIR variant
  * port to standard C++ smart pointers where possible
  * kmemoryinfo class
  * KPluginFactory: Provide better context in error message if instance could not be created
  * KJob: add method to check if job was started with exec()
  * Add autotest for KStringHandler::lsqueeze/csqueeze/rsqueeze
  * new util ksandbox
  * KDirWatch: handle IN_Q_OVERFLOW events
  * KProcess: wrap Qt5-only QProcess API also with Qt version check
  * KListOpenFilesJob: check lsof executable exist in PATH before starting it with QProcess
  * KProcess: replace an assert with a check for empty
  * KAboutData: improve the API docs for LicenseKey enum
  * Install KMemoryInfo headers
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Fix kprocesstest for Qt6
  * autotests: fix kdelibs4configmigratortest for Windows
  * autotests: skip KNetworkMountsTestCanonical::testCanonicalSymlinkPath on Windows
  * autotests: skip KFileUtilsTest::testfindAllUniqueFiles on Windows
  * KNetworkMounts: fix some warnings
  * KPluginMetaData: Fix setting of MetaDataOption when building without deprecations
  * KPluginMetaData: Delegate to other constructors where possible
  * KPluginMetaData: Always initialize d-ptr
  * API dox: typofix, name of header to include
  * API dox: typofix, match @p with the actual params of expandMacro()
  * autotests: check for ZFS and expect failure then
  * autotests: make the FreeBSD test pass
  * processlist: don't call procstat_getpathname() at all
  * ListOpenFilesJob: avoid creating the processlist on FreeBSD multiple times
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Add default argument for KPluginFactory::create where no keyword
    and args have to be specified
  * CI: require tests to pass on Linux
  * Also wrap Kdelibs4ConfigMigrator in a QT_VERSION check for Qt6
  * Optimize KPluginMetaData::findPluginById by using QPluginLoader directly
  * Remove *.doc pattern for text/plain
  * KPluginMetaData: find plugins in the directory of the executable, too
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Add Qt6 Android CI
  * Deprecate KPluginMetaData::fromDesktopFile
  * KPluginMetaDataTest: Explicitly call dedicated constructors
  * KPluginMetaData: Emit runtime deprecation warnings for deprecated code path
  * KPluginMetaData: Add note for deprecated code paths to constructor
  * KPluginMetaData: Use QFileInfo::completeBaseName for deriving plugin id
  * Remove broken Python bindings generation
  * Downgrade mismatched host tool version to WARNING
  * Add a way to indicate to not show a notification on finished
  * Allow to create valid KPluginMetaData for plugins without embedded JSON metadata
  * Add an OUTPUT_FILE argument to kcoreaddons_desktop_to_json()
  * KSignalHandler: attempt to fix Windows build
  * Add KSignalHandler
  * Build benchmarks of kdirwatch test as separate lib
  * Build benchmarks of ktexttohtml as separate executable
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Search in kf<version> plugin
  * kcoreaddons_target_static_plugins: Use private linking for plugin registration file
  * Fix kprocesslist in Windows
  * Fix kformattest on Windows
  * Fix krandomtest on Windows
  * klibexec helper to resolve libexec path relative
  * Set timezone to what the test expects
  * KPluginMetaDataTest: Fix check for service type querying error essage
  * Fix KPluginMetaDataTest::testPathIsAbsolute
  * desktopfileparser: Avoid a run-time string concatenation
  * KF5CoreAddonsConfig: check desktoptojson version when cross-compiling
  * KPluginMetaData: Fix a typo in a comment
  * desktoptojson: Further improvements to cross-compilation mode
  * Fix kcoreaddons_desktop_to_json when cross-compiling
  * Fix compiler warnings in posix_fallocate_mac.h
  * Add KPluginMetaData::fromJsonFile()
  * KPluginMetadata: store all paths as absolute ones
  * KPluginMetaData::metaDataFileName: Fix broken check if we have the metaDataFileName value set
  * Use directly kf${QT_MAJOR_VERSION} (Volker idea)
  * Use QT_STRINGIFY(QT_VERSION_MAJOR) Instead of the if stuff
  * Use kf6 for installing licenses
  * Utilize ECMDeprecationSettings to manage deprecate Qt API
  * kcoreaddons_add_plugin: Throw error when we have unparsed args
  * Add CI qt6 support
  * Port deprecated enum in qt6
  * Need to build static lib
  * Improve formatRelativeDateTime
  * KProcessList: Remove dead Q_OS_FREEBSD branches
  * Improve error message for KPluginFactory::loadFactory
  * Add missing copying of error text in KPluginFactory::instantiatePlugin
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Introduce K_PLUGIN_CLASS macro for creating plugin factory without metadata
  * Don't hardcode kservicestypes5 as search path
  * Put QT_VERSION check around Kdelibs4Migration class
  * FindProcstat: Fix CMake warning and use an imported target
  * Don't put the plugins in a "/plugins" sub-dir in the builddir
  * KPluginFactory: report errors from QPluginLoader
  * Use directly stream operators
  * Now it returns qsizetype in qt6
  * KF5CoreAddonsMacros: Replace "." with "_" for
    KPLUGINFACTORY_PLUGIN_CLASS_INTERNAL_NAME compile definition
  * Clarify deprecation docs of KPluginLoader::factory
  * Write value of QT_MAJOR_VERSION in cmake config file
  * Build system changes to compile against Qt6
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * KF5CoreAddonsMacros: Replace "-" with "_" for KPLUGINFACTORY_PLUGIN_CLASS_INTERNAL_NAME
    compile definition
  * Compile against Qt6
  * Allow reading enabled state from KPluginMetaData using templated method
  * KF5CoreAddonsMacros: Build static plugins as static libs
  * Store KDE specific static plugin in seperate map
  * KF5CoreAddonsMacros: Clean up cached plugin names after each CMake run
  * Make KPluginMetaData::isStaticPlugin public
  * kcoreaddons_add_plugin: Set property for file name
  * Add assertion to make sure we have a d-ptr in KPluginMetaData::getStaticPlugin
  * Create kcoreaddons_target_static_plugins cmake function
  * Allow KPluginMetaData::findPlugins to return static plugins
  * kcoreaddons_add_plugin: Allow creation of static plugins
  * Allow KPluginMetaData to represent static plugins
  * Create KPluginFactory::create method for loading KPart without keyword
  * Deprecate KPluginFactory::create overload taking plugin keyword
  * Deprecate KPluginFactory::registerPlugin(QString, CreateInstance*) methods
  * Deprecate KPluginFactory::registerPlugin overloads taking keyword
  * KPluginFactory: Use overload instead of default arg for registerPlugin keyword parameter
  * Add missing include guard for kjsonutils.h
  * Deprecate KPluginMetaData::serviceTypes
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Too many changes to list here.
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
  * KStringHandler: add a new perlSplit() overload that takes a QStringView
  * ktexttohtml: port QStringRef (deprecated) to QStringView and minor refactor
  * Port QStringRef (deprected) to QStringView
  * Deprecate KPluginMetaData::extraInformation
  * Don't forward-declare QVector
  * Fix python bindings generation
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Too many changes since 5.85.0, only listing bugfixes:
  * Fix issue when building KCrash static (kde#440416)
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Too many changes to list here.
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * kdirwatch_stat_unittest: Increase timeout for slow systems
  * Add new KAboutComponent for third party libs, data, etc.
  * Fix incorrect HAVE_SYS_INOTIFY_H check
  * kfuzzymatcher: Add matchedRanges to get ranges where matches occurred
  * KPluginMetaData: Remove ServiceTypes from JSON code sample
  * KPluginMetaData: Create findPluginById method which prefers file name
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Build KDirWatch tests without threads on windows
  * Clean up Threads CMake code
  * kcoreaddons_add_plugin: make SOURCES argument optional
  * Bump required CMake version to 3.16
  * KJob: if a delegate is already attached to a job, warn when setJob() is called
  * Make KAboutData::productName accessible for KCrash
  * Do not return duplicate plugins in KPluginLoader::findPlugins
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * KPluginMetaData::instanciate to print the error when it fails
  * Call ecm_install_po_files_as_qm() unconditionally
  * Add SMB2 and CIFS magic numbers
  * KFuzzyMatcher update
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Enable Unicode support in QRegularExpression where needed
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Too many changes since 5.79.0, only listing bugfixes:
  * autotests: Fix autotests to pass under gcc ubsan and leak sanitizer. (kde#433402)
  * kpluginfactory: Use the user-provided base factory in our factory macro. (kde#410851)
  * [KProcessList] Check size of data before accessing it (kde#431334)
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Too many changes to list here.
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Port KJobTrackerInterface to Qt5 connect syntax
  * Fix clazy warnings and silence deprecations
  * KTextToHtml: fix assert due to out of bounds at() call
  * Use flat hierarchy for plugin paths on Android
  * KTextToHtml: minor code optimisation
  * Remove ifdefs, we require Qt 5.14 now
  * Use a separate logging category for desktoptojson's use of desktopfileparser
  * desktop to JSON conversion: ignore "Actions=" entry
  * Deprecate KProcess::pid()
  * ktexttohtml: fix KTextToHTMLHelper usage
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * [ktexttohtml] Add test case for empty text
  * Make int to QChar conversion explicit
  * Remove unused include
  * Guard QRegExp include behind deprecation flag
  * Fix include for NAME_MAX
  * Fix test KFormatTest::formatRelativeDate
  * Avoid to crash when factory is empty (when we return an error)
  * KFormat: Add more relative date time cases
  * Enable KPluginFactory to optionally pass KPluginMetaData to plugins
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * KJob: add setProgressUnit(), to choose how percent is calculated
  * Fix potential memory leak in KAboutData::registerPluginData
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Split suggestName(); the split method doesn't check if file exists
  * KAboutData: deprecate pluginData() & registerPluginData()
  * Avoid copying objects
  * Fix compiler warning when some KDirWatch backends aren't available
  * Don't quit the event loop in KJobTest::slotResult()
  * Use functor-based singleShot() overload in TestJob::start()
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Too many changes since 5.74.0, only listing bugfixes:
  * harden message-based tests against environment (kde#387006)
  * refcount and delete KDirWatchPrivate instances (kde#423928)
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Add *.kcrash glob pattern to KCrash Report MIME type
  * Use Q_DECLARE_OPERATORS_FOR_FLAGS in same namespace as flags definition
  * do not wait for fam events indefinitely (kde#423818)
  * Remove obsolete COPYING files
  * [KFormat] Allow formatting values to arbitrary binary units
  * Make it possible to KPluginMetadata from QML
  * [KFormat] Fix binary example
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use "standard" name for pot files for mimetypes
  * Introduce KRandom::shuffle(container)
  * Use KF-standardized Qt logging categories
  * Apply FreeBSD test hacks only for "fast" (inotify) backends.
  * Add a band-aid in kdirwatch unit test for FreeBSD OS. This makes all tests pass.
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * autotests: try harder making kdirwatch_unittest more robust
  * Tweak KRandom::random deprecation notice
  * KRandom::random -> QRandomGenerator::global()
  * Deprecate KRandom::random
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * autotests: make kdirwatch_stat_unittest more robust.
  * Port deprecated method
  * Fix Bug 422291 - Preview of XMPP URI's in KMail (kde#422291)
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * API dox: use ulong typedef with Q_PROPERTY(percent) to avoid doxygen bug
  * API dox: document Q_DECLARE_FLAGS-based flags
  * Mark ancient KLibFactory typedef as deprecated
  * [KJobUiDelegate] Add AutoHandlingEnabled flag
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * kdirwatch: fix a recently introduced crash (kde#419428)
  * QAtomicInteger::loadRelaxed/storeRelaxed() are available since Qt 5.14
  * Fix Warnings
  * KCoreAddons: Convert license statements to SPDX expressions
  * KPluginMetaData: handle invalid mimetype in supportsMimeType
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Use ecm_qt_install_logging_categories over manual categories file
  * add hint that QIcon can be used as a program logo
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * demote plugin load errors from warning to debug level + reword
  * Document how to filter by servicetype the right way
  * Add perlSplit() overload taking a QRegularExpression
    and deprecate the QRegExp one
  * Add mime type for backtraces saved from DrKonqi
  * Add utility text function KShell::tildeCollapse
  * Port to QMultiHash as QHash::insertMulti is deprecated
  * KPluginMetaData: add initialPreference() getter
  * desktoptojson: also convert InitialPreference key
  * KCoreAddons: fix compilation with qtbase git dev branch
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Too many changes since 5.65.0, only listing bugfixes:
  * [KProcessList] Optimize KProcessList::processInfo (kde#410945)
  * Fix KAutoSaveFile when having a long path (kde#412519)
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Remove unused variable
  * Deprecate KAboutData::fromPluginMetaData, now there is KAboutPluginDialog
  * Add a descriptive warning when inotify_add_watch returned ENOSPC
  * Add test for bug "bug-414360" it's not a ktexttohtml bug
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * These methods were adding in qt5.15
  * Make it compile against qt5.15 without deprecated method
  * KCoreAddons: make programIconName() available to KConfigWidgets and KXmlGui
  * KProcessInfoList -- add proclist backend for FreeBSD
  * Fix grammar
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes to list here.
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * autotests: split up kprocesstest to fix compilation with Qt 5.14
  * Use QLatin1String here
  * Q_UNUSED doesn't need a ; after it.
  * [KProcessList] Split command line and process name
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Remove extra ';'
  * autotest: fix kformattest to ignore translations + QStringLiteral fix on Windows
  * Add function to suggest a unique filename
  * Fix build after 0b2fe3cf21
  * Remove unused includes
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop patch to support Qt 5.9:
  * 0001-Do-not-use-functor-if-Qt-lt-5.10.patch
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * KPluginMetaData: use Q_DECLARE_METATYPE
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * Fix compliation for python bindings (kde#407306)
  * Avoid method name clash in windows KProcessList backend
  * Add namespace to windows kprocesslist clas
  * Fix windows KProcessList return type
  * Add GetProcessList for retrieving the list of currently active processes
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * Fix wrong "Unable to find service type" warnings
  * New class KOSRelease - a parser for os-release files
  * Fix bug about "** foo **"
  * Not necessary to have %%2 here as we use %%1
  * Skip running benchmarks when in debug mode.
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Fix "* foo *" we don't want to bold this string.
  * Fix Bug 401996 - clicking contact web url => uncomplete url is selected (kde#401996)
  * autotests: comment out verbose output from KDirWatch
  * Print strerror when inotify fails (typical reason: "too many open files").
  * Port to qregularexpression + simplify it. all autotest ok
  * Add more autotest
  * Fix bug when we have several space
  * Fix compilation with Android API level >= 26
  * Add Q_EMIT to emit signal call
  * port to std::sort
  * Use range-based for loop
  * Make it compile without foreach
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Fix compile kpimtextedit when we remove all deprecated method against
  * Port deprecated methods
  * Namespace find_file call
  * Create tel: links for phone numbers
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Do-not-use-functor-if-Qt-lt-5.10.patch to revert the removal of
  support for Qt 5.9
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * delete copy constructor and assignment operator of some public classes
  * delete copy constructor and assignment operator of some internal classes
  * Remove check for Qt version 5.10
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Use for(...:...) + initialize variables
  * cmake macros: Port away from deprecated ECM var in kcoreaddons_add_plugin (kde#401888)
  * make units and prefixes of formatValue translatable
  * make it build
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.1
  * Hotfix release to fix a build problem
- Changes since 5.53.0:
  * make it build
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Make it possible to use KAboutData/License/Person from QML
  * KPluginFactory: fix create() apidox
  * Fix crash if XDG_CACHE_HOME directory is too small or out of space (kde#400610)
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * autotests: repair "detecting hardlink change" with stat/qfswatch
  * Minor: Use nullptr
  * Add to categories files. Use new syntax
  * Use qEnvironmentVariableIntValue
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Remove misleading use of KDE_INSTALL_PYTHONBINDINGSDIR
  * Use QString's multi-arg with multiple string args
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Don't remove space between two url when line start with " (kmail bug)
  * Add kmail bug. Need to understand why it eats space
  * Add more autotest
  * KPluginLoader: use '/' even on Windows, libraryPaths() returns paths with '/'
  * autotests: add debug output for plugin dirs, to investigate Purpose CI on Windows
  * KPluginMetaData: convert empty string to empty stringlist.
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Fix overflow in rounding code (kde#397008)
  * API dox: remove not-to-be-there ":"s behind "@note"
  * API dox: talk about nullptr, not 0
  * KFormat: Replace unicode literal with unicode codepoint to fix MSVC build
  * KFormat: Add unit tests for mili/micro SI prefixes
  * KFormat: fix typo in SI prefix name enum
  * KFormat: correct @since tag for new KFormat::formatValue
  * KFormat: Allow usage of quantities beyond bytes and seconds
  * Correct KFormat::formatBytes examples
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Remove QT definitions duplicated from KDEFrameworkCompilerSettings
  * Make sure that it compiles with strict compile flags
  * Remove unused key X-KDE-DBus-ModuleName from test servicetype metadata
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * None
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Use override
  * [KUser] Check whether .face.icon is actually readable before returning it
  * We need ";" for windows compiler (on last gcc it works without problem)
  * Revert "Revert "Warning--""
  * Fix pedantic warnings
  * Revert "Warning--"
  * Warning--
  * KJob public signals
  * Fix compiler warning under Clang
  * [kcoreaddons] convert to new connect syntax
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Add missing override
  * Return when url is empty
  * Use ecm_setup_qtplugin_macro_names
  * Remove not necessary QtCore and co
  * Cleanup m_inotify_wd_to_entry before invalidating Entry pointers (kde#390214)
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Cleanup m_inotify_wd_to_entry before invalidating Entry pointers (kde#390214)
  * kcoreaddons_add_plugin: remove effectless OBJECT_DEPENDS on json file
  * Help automoc to find metadata JSON files referenced in the code
  * kcoreaddons_desktop_to_json: note the generated file in the build log
  * Bump shared-mime-info to 1.3
  * Use override keyword here
  * Introduce K_PLUGIN_CLASS_WITH_JSON
  * KUrlMimeData: port to QStringLiteral
  * Increase timeout in the hope of fixing test failure on the CI
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * KUrlMimeData: fix handling of PreferLocalUrls
  * Match also spdx keys LGPL-2.1 & LGPL-2.1+
  * Use the much faster urls() method from QMimeData
  * Next try to fix build on windows
  * Make it compiles on windows
  * Compile commenting remove_defintion(QT_NO_CAST_FROM_ASCII )
  * Optimize inotify KDirWatch backend: map inotify wd to Entry
  * Optimize: use QMetaObject::invokeMethod with functor
  * Add benchmarks for KDirWatch
  * Use QSignalSpy::wait instead of QTest::wait where possible
  * Verify that the file was opened
  * Verify that the path is valid and writable
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Extend CMAKE_AUTOMOC_MACRO_NAMES also for own build
  * Match license keys by spdx
  * Remove cmake 3.10+ warning for users of K_PLUGIN_FACTORY and K_PLUGIN_FACTORY_WITH_JSON
  * Improve apidox of KJobTrackerInterface
  * Minor
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Autotest: fix for HOME having a trailing slash
  * Input validation of SubJobs
  * Warn about errors when parsing json files
  * Install mimetype definitions for kcfg/kcfgc/ui.rc/knotify & qrc files
  * Add a new function to measure the length by text.
  * Keep widgets optional, as it's a test
  * Look for Qt5 rather than Qt5Widgets
  * Remove unused code
  * Fix KAutoSave bug on file with white space in it
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * KCompositeJob: port to new connect syntax. Improves performance.
  * fix URL detection with double urls like "http://www.foo.bar<http://foo.bar/>"
  * DesktopFileParser: improve error reporting, fix coding style
  * Remove double ";"
  * Use https for KDE urls
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * desktoptojson: Improve legacy service type detection heuristic. (kde#384037)
  * modernise debugging.
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * DesktopFileParser: add fallback lookup in ":/kservicetypes5/*"
  * Add support for uninstalled plugins in kcoreaddons_add_plugin
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * desktopfileparser: Fix non-compliant key/value parsing. (kde#310674)
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Remove unused init() declaration from K_PLUGIN_FACTORY_DECLARATION_WITH_BASEFACTORY_SKEL
  * Restore the QCoreApplication library paths at the end of the tests that change it.
  * API dox: add note about moc include need with K_PLUGIN_FACTORY(_WITH_JSON)
  * add KAboutLicense::spdx and introduce orLater qualification
  * API dox: for deprecated tell since and what to use instead
  * disable compiler warning on testing deprecated function
  * use an initializer list instead of calling insert a million times
  * kdirwatch: Avoid potential crash if d-ptr destroyed before KDirWatch. (kde#381583)
  * Fix display of formatDuration with rounding. (kde#360681,kde#382069)
  * Use explicit flag value instead of nullptr
  * API dox: use @p to refer to argument in running text, not @arg
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Use FindInotify.cmake to decide wheter inotify is available.
  * [FEATURE] Option to build & install QCH file with the public API dox
  * Fix KDirWatch unit test to use set KDIRWATCH_METHOD again
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Fixes to 26a262180155
  * Ensure proper per thread seeding in KRandom.
  * API dox: in example use KDBusService only after commandline is handled
  * API dox: Use doxygen notation to have comments used
  * API dox: add some minimal docs to more namespace
  * API dox: note CamelCase includes by @class tag with more classes
  * Remove qDebug from removeDir/removeFile as discussed in https://phabricator.kde.org/D5856
  * Do not watch QRC's paths (kde#374075)
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix the @see function names
  * Add .arcconfig
  * API dox: more info about KAboutData's orgDomain/desktopFileName properties
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * explicitly set NO_CMAKE_FIND_ROOT_PATH
  * Upgrade KF5 version to 5.33.0.
  * Mac OS (X) has a POSIX-compliant /bin/sh too
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Fix compilation with Qt 5.6.
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Exclude (6)
  * Move the isDir() outside of the loop, as spotted by Milian.
  * KDirWatch: replace QList<Client *> by std::vector<Client> to save on new/delete.
  * Upgrade KF5 version to 5.32.0.
  * KDirWatch: fix memory leak on destruction.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
- Drop parse-the-desktop-file-2-times.patch
* Wed Jan 11 2017 hrvoje.senjan@gmail.com
- Add parse-the-desktop-file-2-times.patch: keeping backward
  compatibility is backward
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * KTextToHtml: fix bug "[1] added at the end of a hyperlink"
    (kde#343275)
  * KUser: Only search for an avatar if loginName isn't empty
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Display bad url
  * Load user avatars from AccountsServicePath if it exists
    (kde#370362)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  9 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Register QPair<QString,QString> as metatype in KJobTrackerInterface
  * Don't convert as url an url which has a double-quote character
    (boo#1002977, CVE-2016-7966)
  * Windows compile fix
  * Fix very old bug when we remove space in url as "foo <<url> <url>>"
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
- Drop upstreamed
  0001-Fix-very-old-bug-when-we-remove-space-in-url-as-foo-.patch
  0002-Don-t-convert-as-url-an-url-which-has-a.patch
* Thu Oct  6 2016 hrvoje.senjan@gmail.com
- Added 0001-Fix-very-old-bug-when-we-remove-space-in-url-as-foo-.patch
  0002-Don-t-convert-as-url-an-url-which-has-a.patch (CVE-2016-7966)
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Install known licenses and find them at runtime (regression fix)
    (kde#353939)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Print the failing plugin when notifying a cast warning
  * [kshareddatacache] Fix invalid use of & to avoid unaligned reads
  * Kdelibs4ConfigMigrator: skip reparsing if nothing was migrated
  * krandom: Add testcase to catch bug 362161 (failure to auto-seed)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Provide a way to disable inotify use in KDirWatch
  * Fix KAboutData::applicationData() to init from current
    Q*Application metadata
  * Make clear that KRandom is not recommended for cryptography purposes
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
- Drop upstreamed 0001-Missing-rand-qrand.patch
* Wed Apr 27 2016 hrvoje.senjan@gmail.com
- Added 0001-Missing-rand-qrand.patch (kde#362161)
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Fix kcoreaddons_desktop_to_json() on windows
  * Fix linking to a Threads library
  * Add stubs to allow compilation on Android
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Fix Kdelibs4 config migration for Windows
  * Add API to get Frameworks runtime version info
  * KRandom: Don't use up 16K of /dev/urandom to seed rand()
    (kde#359485)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
- Use %%mime_database_post(un) macros
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Add KAboutData::fromPluginMetaData(const KPluginMetaData &plugin)
  * Add KPluginMetaData::copyrightText(), extraInformation() and
    otherContributors()
  * Add KPluginMetaData::translators() and KAboutPerson::fromJson()
  * Fix use-after-free in desktop file parser
  * Make KPluginMetaData constructible from a json path
  * desktoptojson: make missing service type file an error for the binary
  * Make calling kcoreaddons_add_plugin without SOURCES an error
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * KAboutData: Allow https:// and other URL schemas in homepage.
    (kde#355508)
  * Repair MimeType property when using kcoreaddons_desktop_to_json()
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * KAboutData: apidoc "is is" -> "is" addCredit(): ocsUserName -> ocsUsername
  * KJob::kill(Quiet) should also exit the event loop
  * Add support for desktop file name to KAboutData
  * Use correct escaping character
  * Reduce some allocations
  * Make KAboutData::translators/setTranslators simple
  * Fix setTranslator example code
  * desktopparser: skip the Encoding= key
  * desktopfileparser: Address review comments
  * Allow setting service types in kcoreaddons_desktop_to_json()
  * desktopparser: Fix parsing of double and bool values
  * Add KPluginMetaData::fromDesktopFile()
  * desktopparser: Allow passing relative paths to service type files
  * desktopparser: Use more categorized logging
  * QCommandLineParser uses -v for --version so just use --verbose
  * Remove lots of duplicated code for desktop{tojson,fileparser}.cpp
  * Parse ServiceType files when reading .desktop files
  * Make SharedMimeInfo an optional requirement
  * Remove call to QString::squeeze()
  * desktopparser: avoid unnecessary utf8 decoding
  * desktopparser: Don't add another entry if entry ends in a separator
  * KPluginMetaData: Warn when a list entry is not a JSON list
  * Add mimeTypes() to KPluginMetaData
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * KShell::splitArgs: only ASCII space is a separator, not unicode
    space U+3000 (kde#345140)
  * KDirWatch: fix crash when a global static destructor uses
    KDirWatch::self() (kde#353080)
  * Fix crash when KDirWatch is used in Q_GLOBAL_STATIC.
  * KDirWatch: fix thread safety
  * Clarify how to set KAboutData constructor arguments.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Add Kdelibs4Migration::kdeHome() for cases not covered by resources
  * Fix tr() warning
  * Fix KCoreAddons build on Clang+ARM
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * KDirWatch: Only establish a connection to FAM if requested
  * Allow filtering plugins and applications by formfactor
  * Make it possible to use desktoptojson from different sources
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * New KPluginLoader::findPluginById() convenience API
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * New cmake macro kcoreaddons_add_plugin to create
    KPluginLoader-based plugins more easily.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * KPluginMetadata: add support for Hidden key
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * KAboutData: Call addHelpOption and addVersionOption
    automatically, for convenience and consistency
  * KAboutData: Bring back "Please use http://bugs.kde.org
    to report bugs." when no other email/url is set
  * KAutoSaveFile: allStaleFiles() now works as expected
    for local files, fixed staleFiles() too
  * KRandomSequence now uses int's internally and exposes
    int-api for 64-bit unambiguity
  * Mimetype definitions: *.qmltypes and *.qmlproject files
    also have the text/x-qml mime type
  * KShell: make quoteArgs quote urls with QChar::isSpace(),
    unusual space characters were not handled properly
  * KSharedDataCache: fix creation of directory containing
    the cache (porting bug)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * KDirWatch can now watch /dev/shm as well (kde#314982)
  * KDELibs4Migration now always returns an absolute path
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Add KTextToHTML class for plaintext->HTML conversion
  * Add KPluginMetaData::metaDataFileName()
  * Allow to read KPluginMetaData from .desktop files
  * Kdelibs4Migration now gives priority to distro-provided
    KDE4_DEFAULT_HOME
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
- Drop 0001-Let-Kdelibs4Migration-searches-in-.kde4-first-it-s-p.patch,
  merged upstream
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * Various build fixes (QNX, Ubuntu 14.04)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * Kdelibs4Migration: allow distributions to set
    _KDE4_DEFAULT_HOME_POSTFIX so that the kde4 home
    is found properly.
  * Compilation fixes for MSVC and gcc 4.5
  * Turn KFormat into a Q_GADGET so we can expose its
    properties to QML indirectly
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Pass -DKDE4_DEFAULT_HOME=".kde4", used in kdelibs4migration class
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * KCoreAddons: Mark KAboutData::setProgramIconName() as deprecated,
    it did not do anything.
    Use QApplication::setWindowIcon(QIcon::fromTheme("...")) instead.
  * KCoreAddons: new classes Kdelibs4ConfigMigrator and KPluginMetaData
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Tue Aug 26 2014 hrvoje.senjan@gmail.com
- Added 0001-Let-Kdelibs4Migration-searches-in-.kde4-first-it-s-p.patch:
  Let Kdelibs4Migration searches in .kde4 first, it's possible that
  some users have ancient unused config in .kde, and openSUSE
  has .kde4 as default
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
- Harden required Qt5 libs versions
- Pass the location of lconvert executable
- Don't own standard directories
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Added libqt5-linguist-devel BuildRequires
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Wed Feb 19 2014 hrvoje.senjan@gmail.com
- Create a separate (binary) kcoreaddons package, so library
  package adheres to shlib policy
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kcoreaddons package
